#!/bin/bash
# Script to make and install all of the relevant rayinvr programs, without the 
# hassle of doing it for each directory.

G77=g77
BIN=/usr/local/rayinvr_g77/bin
GCC=gcc

#compiling rayinvr
cd rayinvr
echo "compiling xrayinvr"

$G77 -O -c main.f
$G77 -O -c trc.f
$G77 -O -c atrc.f
$G77 -O -c adjpt.f
$G77 -O -c rngkta.f
$G77 -O -c plt.f
$G77 -O -c misc.f
$G77 -O -c inv.f
$G77 -O -c hdw.f
$G77 -O -c calmod.f
$G77 -O -c blkdat.f
$G77 -O -c ../pltlib/pltsub.f
$G77 -O -c ../pltlib/xpltlib.f
$GCC -O -I/usr/X11R6/include -c ../pltlib/xbuplot.c

$G77 -o main main.o trc.o atrc.o adjpt.o rngkta.o plt.o misc.o inv.o hdw.o \
calmod.o blkdat.o pltsub.o xpltlib.o xbuplot.o -L/usr/X11R6/lib -lX11
mv main $BIN/xrayinvr



# compiling pltsyn
cd ../pltsyn
echo "compiling xpltsyn"

$G77 -O -c main.f
$G77 -O -c pltsec.f
$G77 -O -c misc.f
$G77 -O -c blkdat.f
$G77 -O -c ../pltlib/pltsub.f
$G77 -O -c ../pltlib/xpltlib.f
$GCC -O -I/usr/X11R6/include -c ../pltlib/xbuplot.c

$G77 -o main main.o pltsec.o misc.o blkdat.o pltsub.o xpltlib.o xbuplot.o \
 -L/usr/X11R6/lib -lX11
mv main $BIN/xpltsyn


# compiling rayplot
cd ../rayplot
echo "compiling xrayplot"

$G77 -c rayplot.f
$G77 -O -c ../pltlib/pltsub.f
$G77 -O -c ../pltlib/xpltlib.f
$GCC -O -I/usr/X11R6/include -c ../pltlib/xbuplot.c

$G77 -o main rayplot.o pltsub.o xpltlib.o xbuplot.o -L/usr/X11R6/lib -lX11
mv main $BIN/xrayplot


# compiling tramp
cd ../tramp
echo "compiling xtramp"

$G77 -O -c main.f
$G77 -O -c trc.f
$G77 -O -c atrc.f
$G77 -O -c adjpt.f
$G77 -O -c rngkta.f
$G77 -O -c plt.f
$G77 -O -c misc.f
$G77 -O -c amp.f
$G77 -O -c hdw.f
$G77 -O -c calmod.f
$G77 -O -c blkdat.f
$G77 -O -c ../pltlib/pltsub.f
$G77 -O -c ../pltlib/xpltlib.f
$GCC -O -I/usr/X11R6/include -c ../pltlib/xbuplot.c

$G77 -o main main.o trc.o atrc.o adjpt.o rngkta.o plt.o misc.o amp.o hdw.o \
calmod.o blkdat.o pltsub.o xpltlib.o xbuplot.o -L/usr/X11R6/lib -lX11
mv main $BIN/xtramp


# compiling vmodel
cd ../vmodel
echo "compiling xvmodel"

$G77 -O -c main.f
$G77 -O -c plt.f
$G77 -O -c misc.f
$G77 -O -c blkdat.f
$G77 -O -c ../pltlib/pltsub.f
$G77 -O -c ../pltlib/xpltlib.f
$GCC -O -I/usr/X11R6/include -c ../pltlib/xbuplot.c

$G77 -o main main.o plt.o misc.o blkdat.o pltsub.o xpltlib.o xbuplot.o \
-L/usr/X11R6/lib -lX11
mv main $BIN/xvmodel


cd ..

# compiling all of the miscellaneous fortran programs
# The ones that dont compile are probably not important
# but can be modified if needed.
echo "compiling misc programs"
for i in `ls misc/*.f`;
do
    # moving all the compiled misc programs to $BIN
    # and removing the .f from the names
    $G77 $i -o $BIN/`basename $i .f`
done

# compiling c2v, v2c
echo "compiling c2v, v2c"
$G77 c2v/c2v.f -o $BIN/c2v
$G77 c2v/v2c.f -o $BIN/v2c

echo "rayinvr compiling and installation complete"
